﻿using System;
using System.Windows.Forms;
using Eneter.Messaging.EndPoints.Rpc;
using Eneter.Messaging.MessagingSystems.MessagingSystemBase;
using Eneter.Messaging.MessagingSystems.TcpMessagingSystem;

namespace CalculatorClient2
{
    public partial class Form1 : Form
    {
        // Declare same interface as in Java service application.
        // Note: do not forget case-sensitiveness. If Java methods start with
        //       small letters then also these methods must start with small letters.
        public interface ICalculator
        {
            double sum(double a, double b);
            double subtract(double a, double b);
            double multiplay(double a, double b);
            double divide(double a, double b);
        }

        private IRpcClient<ICalculator> myRpcClient;

        public Form1()
        {
            InitializeComponent();

            // Get RPC client for declared service interface.
            IRpcFactory anRpcFactory = new RpcFactory();
            myRpcClient = anRpcFactory.CreateClient<ICalculator>();

            // Attach output channel and be able to communicate.
            TcpMessagingSystemFactory aMessaging = new TcpMessagingSystemFactory();
            IDuplexOutputChannel anOutputChannel = aMessaging.CreateDuplexOutputChannel("tcp://127.0.0.1:8045/");
            myRpcClient.AttachDuplexOutputChannel(anOutputChannel);
        }


        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            // Stop listening by detaching the input channel.
            myRpcClient.DetachDuplexOutputChannel();
        }

        private void SumButton_Click(object sender, EventArgs e)
        {
            double a = double.Parse(Number1TextBox.Text);
            double b = double.Parse(Number2TextBox.Text);
            ResultLabel.Text = myRpcClient.Proxy.sum(a, b).ToString();
        }
         
        private void SubtractButton_Click(object sender, EventArgs e)
        {
            double a = double.Parse(Number1TextBox.Text);
            double b = double.Parse(Number2TextBox.Text);
            ResultLabel.Text = myRpcClient.Proxy.subtract(a, b).ToString();
        }

        private void MultiplyButton_Click(object sender, EventArgs e)
        {
            double a = double.Parse(Number1TextBox.Text);
            double b = double.Parse(Number2TextBox.Text);
            ResultLabel.Text = myRpcClient.Proxy.multiplay(a, b).ToString();
        }

        private void DivideButton_Click(object sender, EventArgs e)
        {
            double a = double.Parse(Number1TextBox.Text);
            double b = double.Parse(Number2TextBox.Text);
            ResultLabel.Text = myRpcClient.Proxy.divide(a, b).ToString();
        }
    }
}
